%global eclipse_base     %{_libdir}/eclipse
%global eclipse_dropin   %{_datadir}/eclipse/dropins

Name:		eclipse-gef
Version:	3.7.0
Release:	%mkrel 3
Summary:	Graphical Editing Framework (GEF) Eclipse plugin
Group:		Development/Java
License:	EPL
URL:		http://www.eclipse.org/gef/

# source tarball and the script used to generate it from upstream's source control
# script usage:
# $ sh get-gef.sh
Source0:	gef-%{version}.tar.gz
Source1:	get-gef.sh

BuildArch:	noarch

BuildRequires:	java-devel
BuildRequires:	java-javadoc
BuildRequires:	jpackage-utils
BuildRequires:	eclipse-pde >= 1:3.6.0
Requires:	java
Requires:	jpackage-utils
Requires:	eclipse-platform >= 1:3.6.0

%description
The Graphical Editing Framework (GEF) allows developers to create a rich
graphical editor from an existing application model. GEF is completely
application neutral and provides the groundwork to build almost any
application, including but not limited to: activity diagrams, GUI builders,
class diagram editors, state machines, and even WYSIWYG text editors.

%package	sdk
Summary:	Eclipse GEF SDK
Group:		Development/Java
Requires:	java-javadoc
Requires:	eclipse-pde >= 1:3.5.1
Requires:	%{name} = %{version}-%{release}

%description sdk
Documentation and source for the Eclipse Graphical Editing Framework (GEF).

%package	examples
Summary:	Eclipse GEF examples
Group:		Development/Java
Requires:	%{name} = %{version}-%{release}

%description examples
Installable versions of the example projects from the SDK that demonstrates how
to use the Eclipse Graphical Editing Framework (GEF) plugin.

%prep
%setup -q -n gef-%{version}

# make sure upstream hasn't sneaked in any jars we don't know about
JARS=""
for j in `find -name "*.jar"`; do
  if [ ! -L $j ]; then
    JARS="$JARS $j"
  fi
done
if [ ! -z "$JARS" ]; then
   echo "These jars should be deleted and symlinked to system jars: $JARS"
   exit 1
fi

%build
# We build the gef and examples features seperately, rather than just
# building the "all" feature, because it makes the files section easier to
# maintain (i.e. we don't have to know when upstream adds a new plugin)

# Note: Use the tag in get-gef.sh as the context qualifier because it's
#       later than the tags of the individual plugins.
OPTIONS="-DforceContextQualifier=v20110622-0958"

# build gef features
eclipse-pdebuild -f org.eclipse.gef -a "$OPTIONS"
eclipse-pdebuild -f org.eclipse.zest -a "$OPTIONS"
eclipse-pdebuild -f org.eclipse.gef.sdk \
  -a "$OPTIONS -DJAVADOC14_HOME=%{java_home}/bin"
eclipse-pdebuild -f org.eclipse.zest.sdk \
  -a "$OPTIONS -DJAVADOC14_HOME=%{java_home}/bin"

# build examples features
eclipse-pdebuild -f org.eclipse.gef.examples

%install
install -d -m 755 %{buildroot}%{eclipse_dropin}
unzip -q -n -d %{buildroot}%{eclipse_dropin}/gef          build/rpmBuild/org.eclipse.gef.zip
unzip -q -n -d %{buildroot}%{eclipse_dropin}/gef          build/rpmBuild/org.eclipse.zest.zip
unzip -q -n -d %{buildroot}%{eclipse_dropin}/gef-sdk      build/rpmBuild/org.eclipse.gef.sdk.zip
unzip -q -n -d %{buildroot}%{eclipse_dropin}/gef-sdk      build/rpmBuild/org.eclipse.zest.sdk.zip
unzip -q -n -d %{buildroot}%{eclipse_dropin}/gef-examples build/rpmBuild/org.eclipse.gef.examples.zip

# the non-sdk builds are a subset of the sdk builds, so delete duplicate features & plugins from the sdks
(cd %{buildroot}%{eclipse_dropin}/gef-sdk/eclipse/features && ls %{buildroot}%{eclipse_dropin}/gef/eclipse/features | xargs rm -rf)
(cd %{buildroot}%{eclipse_dropin}/gef-sdk/eclipse/plugins  && ls %{buildroot}%{eclipse_dropin}/gef/eclipse/plugins  | xargs rm -rf)

%files
%{eclipse_dropin}/gef
%doc org.eclipse.gef-feature/rootfiles/*

%files sdk
%{eclipse_dropin}/gef-sdk
%doc org.eclipse.gef.sdk-feature/rootfiles/*

%files examples
%{eclipse_dropin}/gef-examples
%doc org.eclipse.gef.examples-feature/rootfiles/*


%changelog

* Fri Jan 11 2013 umeabot <umeabot> 3.7.0-3.mga3
+ Revision: 349432
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 sander85 <sander85> 3.7.0-2.mga3
+ Revision: 343720
- Fix build

* Thu Nov 24 2011 gil <gil> 3.7.0-1.mga2
+ Revision: 171747
- update to 3.7.0

* Mon May 16 2011 ahmad <ahmad> 3.6.2-2.mga1
+ Revision: 99293
- Fix sub-packages groups (mga#1302)

* Tue May 10 2011 dmorgan <dmorgan> 3.6.2-1.mga1
+ Revision: 96902
- imported package eclipse-gef

